==> naive-ui-2.11.5.tgz: package/es/dropdown/src/DropdownGroup.js <==
import { defineComponent, Fragment, h } from 'vue';
import { warn } from '../../_utils';
import NDropdownOption from './DropdownOption';
import NDropdownDivider from './DropdownDivider';
import NDropdownGroupHeader from './DropdownGroupHeader';
import { isDividerNode, isGroupNode } from './utils';
export default defineComponent({
    name: 'NDropdownGroup',
    props: {
        clsPrefix: {
            type: String,
            required: true
        },
        tmNode: {
            type: Object,
            required: true
        },
        parentKey: {
            type: [String, Number],
            default: null
        }
    },
    render() {
        const { tmNode, parentKey, clsPrefix } = this;
        const { children } = tmNode;
        return (h(Fragment, null,
            h(NDropdownGroupHeader, { clsPrefix: clsPrefix, tmNode: tmNode, key: tmNode.key }), children === null || children === void 0 ? void 0 :
            children.map((child) => {
                if (isDividerNode(child.rawNode)) {
                    return h(NDropdownDivider, {
                        clsPrefix,
                        key: child.key
                    });
                }
                if (isGroupNode(child.rawNode)) {
                    warn('dropdown', '`group` node is allowed to be put in `group` node.');
                    return null;
                }
                return (h(NDropdownOption, { clsPrefix: clsPrefix, tmNode: child, parentKey: parentKey, key: child.key }));
            })));
    }
});

==> naive-ui-2.11.10-0.tgz: package/es/dropdown/src/DropdownGroup.js <==
import { defineComponent, Fragment, h } from 'vue';
import { warn } from '../../_utils';
import NDropdownOption from './DropdownOption';
import NDropdownDivider from './DropdownDivider';
import NDropdownGroupHeader from './DropdownGroupHeader';
import { isDividerNode, isGroupNode } from './utils';
export default defineComponent({
    name: 'NDropdownGroup',
    props: {
        clsPrefix: {
            type: String,
            required: true
        },
        tmNode: {
            type: Object,
            required: true
        },
        parentKey: {
            type: [String, Number],
            default: null
        }
    },
    render() {
        const { tmNode, parentKey, clsPrefix } = this;
        const { children } = tmNode;
        return (h(Fragment, null,
            h(NDropdownGroupHeader, { clsPrefix: clsPrefix, tmNode: tmNode, key: tmNode.key }), children === null || children === void 0 ? void 0 :
            children.map((child) => {
                if (isDividerNode(child.rawNode)) {
                    return h(NDropdownDivider, {
                        clsPrefix,
                        key: child.key
                    });
                }
                if (isGroupNode(child.rawNode)) {
                    warn('dropdown', '`group` node is not allowed to be put in `group` node.');
                    return null;
                }
                return (h(NDropdownOption, { clsPrefix: clsPrefix, tmNode: child, parentKey: parentKey, key: child.key }));
            })));
    }
});
